<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Programmname</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Verwendung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="106"/>
        <source>Dock Preview</source>
        <translation>Dock-Vorschau</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="118"/>
        <source>Add New Application</source>
        <translation>neue Anwendung hinzufügen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="131"/>
        <source>Command</source>
        <translation>Befehl</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="301"/>
        <source>Add application</source>
        <translation>Anwendung hinzufügen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="393"/>
        <source>Delete this application</source>
        <translation>Diese Anwendung löschen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="124"/>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="154"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="161"/>
        <source>Background</source>
        <translation>Hintergrund</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="379"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="184"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="216"/>
        <location filename="mainwindow.cpp" line="708"/>
        <location filename="mainwindow.cpp" line="735"/>
        <source>Select icon...</source>
        <translation>Symbol auswählen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <location filename="mainwindow.cpp" line="82"/>
        <location filename="mainwindow.cpp" line="582"/>
        <location filename="mainwindow.cpp" line="711"/>
        <source>Select...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="315"/>
        <source>Move right</source>
        <translation>Nach rechts verschieben</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Move left</source>
        <translation>Nach links verschieben</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="478"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="481"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="520"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="523"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="530"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="571"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="103"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Anwendungen nacheinander zum Dock hinzufügen
2. Wählen Sie eine .desktop-Datei aus oder geben Sie einen Befehl für die gewünschte Anwendung ein
3. Wählen Sie Symbol-Attribute für Größe, Hintergrund (schwarz ist Standard) und Rahmen
4. Drücken Sie &quot;Anwendung hinzufügen&quot;, um fortzufahren, oder &quot;Speichern&quot;, um zu beenden.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="590"/>
        <source>black</source>
        <translation>schwarz</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <location filename="mainwindow.cpp" line="591"/>
        <source>white</source>
        <translation>weiß</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="137"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Mit diesem Tool können Sie ein neues Dock mit einer oder mehreren Anwendungen erstellen. Sie können auch ein zuvor erstelltes Dock bearbeiten oder löschen.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="139"/>
        <source>Operation mode</source>
        <translation>Betriebsmodus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="140"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="141"/>
        <source>&amp;Move</source>
        <translation>&amp;Verschieben</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="142"/>
        <location filename="mainwindow.cpp" line="295"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="143"/>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="144"/>
        <source>C&amp;reate</source>
        <translation>E&amp;rstellen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="220"/>
        <source>Dock name</source>
        <translation>Name des Docks</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="221"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Geben Sie den Namen ein, der im Menü angezeigt werden soll:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="293"/>
        <source>Select dock to delete</source>
        <translation>Wählen Sie das zu löschende Dock aus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="294"/>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="295"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Sind Sie sicher, dass Sie %1 löschen möchten?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="295"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="320"/>
        <source>Select dock to move</source>
        <translation>Wählen Sie das zu verschiebende Dock aus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="293"/>
        <location filename="mainwindow.cpp" line="320"/>
        <location filename="mainwindow.cpp" line="454"/>
        <location filename="mainwindow.cpp" line="657"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation>Dock-Dateien (*.mxdk);;Alle Dateien (*.*)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="330"/>
        <location filename="mainwindow.cpp" line="351"/>
        <location filename="mainwindow.cpp" line="666"/>
        <source>Could not open file</source>
        <translation>Datei konnte nicht geöffnet werden</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="453"/>
        <source>Overwrite?</source>
        <translation>Überschreiben?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="453"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Möchten Sie die Dock-Datei überschreiben?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="454"/>
        <source>Save file</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="492"/>
        <source>Dock saved</source>
        <translation>Dock gespeichert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="492"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Das Dock wurde gespeichert

Um das neu erstellte Dock zu bearbeiten, wählen Sie bitte &apos;Ein vorhandenes Dock bearbeiten&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="511"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="513"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="514"/>
        <source>Description goes here</source>
        <translation>Geben Sie hier die Beschreibung ein</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="516"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="517"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="526"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="638"/>
        <source>Select .desktop file</source>
        <translation>.desktop-Datei auswählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="638"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Arbeitsoberflächendateien (*.desktop)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="657"/>
        <source>Select a dock file</source>
        <translation>Eine Dock-Datei auswählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="660"/>
        <source>No file selected</source>
        <translation>Es wurde keine Datei ausgewählt.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="660"/>
        <source>You haven't selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Sie haben keine Dock-Datei ausgewählt
Erstellen Sie stattdessen eine neue Dock-Datei.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="666"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Ausgewählte Datei konnte nicht geöffnet werden.
Stattdessen wurde ein neues Dock erstellt.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="675"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Bearbeiten Sie die Anwendungen nacheinander mit den Schaltflächen Zurück und Weiter.
2. Anwendungen nach Belieben hinzufügen oder löschen
3. Wenn Sie fertig sind, klicken Sie auf Speichern.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="719"/>
        <source>Select icon</source>
        <translation>Symbol auswählen</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="719"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Symbole (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Speicherort Dock</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>ObenMitte</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>UntenLinks</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>UntenMitte</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>ObenLinks</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>ObenRechts</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>LinksMitte</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>RechtsMitte</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>UntenRechts</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>RechtsOben</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>LinksOben</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>LinksUnten</translation>
    </message>
    <message>
        <location filename="picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>RechtsUnten</translation>
    </message>
    <message>
        <location filename="picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Den Speicherort der Dock-Datei auswählen</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="main.cpp" line="57"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Diese Anwendung muss als normaler Benutzer ausgeführt werden.</translation>
    </message>
</context>
</TS>